==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/EventCreationSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.EventCreation;
import io.ciera.tool.sql.architecture.expression.EventCreationSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventCreationSetImpl extends InstanceSet<EventCreationSet,EventCreation> implements EventCreationSet {

    // attributes
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setBlock_number( ref_block_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setStatement_number( ref_statement_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setParent_package( ref_parent_package );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setExpression_number( ref_expression_number );
    }
    @Override
    public void setTarget_expression_number( String ref_target_expression_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setTarget_expression_number( ref_target_expression_number );
    }
    @Override
    public void setEvt_expression_number( String ref_evt_expression_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setEvt_expression_number( ref_evt_expression_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setParent_name( ref_parent_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setBody_name( ref_body_name );
    }
    @Override
    public void setTo_self( boolean m_to_self ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setTo_self( m_to_self );
    }


    // selections
    @Override
    public ExpressionSet R3902_has_target_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EventCreation eventcreation : this ) expressionset.add( eventcreation.R3902_has_target_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R3903_has_base_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EventCreation eventcreation : this ) expressionset.add( eventcreation.R3903_has_base_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EventCreation eventcreation : this ) expressionset.add( eventcreation.R776_is_a_Expression() );
        return expressionset;
    }


    @Override
    public EventCreation nullElement() {
        return EventCreationImpl.EMPTY_EVENTCREATION;
    }

    @Override
    public EventCreationSet emptySet() {
      return new EventCreationSetImpl();
    }

    @Override
    public EventCreationSet value() {
        return this;
    }

    @Override
    public List<EventCreation> elements() {
        return Arrays.asList(toArray(new EventCreation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/EventCreationSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.EventCreation;
import io.ciera.tool.sql.architecture.expression.EventCreationSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventCreationSetImpl extends InstanceSet<EventCreationSet,EventCreation> implements EventCreationSet {

    public EventCreationSetImpl() {
    }

    public EventCreationSetImpl(Comparator<? super EventCreation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setParent_name( ref_parent_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setBlock_number( ref_block_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setStatement_number( ref_statement_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setParent_package( ref_parent_package );
    }
    @Override
    public void setEvt_expression_number( String ref_evt_expression_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setEvt_expression_number( ref_evt_expression_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setBody_name( ref_body_name );
    }
    @Override
    public void setTarget_expression_number( String ref_target_expression_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setTarget_expression_number( ref_target_expression_number );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setExpression_number( ref_expression_number );
    }
    @Override
    public void setTo_self( boolean m_to_self ) throws XtumlException {
        for ( EventCreation eventcreation : this ) eventcreation.setTo_self( m_to_self );
    }


    // selections
    @Override
    public ExpressionSet R3902_has_target_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EventCreation eventcreation : this ) expressionset.add( eventcreation.R3902_has_target_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R3903_has_base_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EventCreation eventcreation : this ) expressionset.add( eventcreation.R3903_has_base_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EventCreation eventcreation : this ) expressionset.add( eventcreation.R776_is_a_Expression() );
        return expressionset;
    }


    @Override
    public EventCreation nullElement() {
        return EventCreationImpl.EMPTY_EVENTCREATION;
    }

    @Override
    public EventCreationSet emptySet() {
      return new EventCreationSetImpl();
    }

    @Override
    public EventCreationSet emptySet(Comparator<? super EventCreation> comp) {
      return new EventCreationSetImpl(comp);
    }

    @Override
    public EventCreationSet value() {
        return this;
    }

    @Override
    public List<EventCreation> elements() {
        return Arrays.asList(toArray(new EventCreation[0]));
    }

}
